jactf.utils.init
================

.. automodule:: jactf.utils.init

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      init_main
      register_rng
      tune_tensorflow
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: init_main

.. autofunction:: register_rng

.. autofunction:: tune_tensorflow


